# slotpy:
## Slide and plot with python

You want to know how the parameters in your large datasets evolve?

Simply click and watch! 

![alt text](https://github.com/Chia-vie/slotpy/blob/main/slotpy_logo_prelim.png)


## Installation

Create a virtual environment:

Either: 
```bash
cd /Path/
python3 -m venv venv/
source venv/bin/activate
```

Or:
```bash
conda create -n slotpy python=3
conda activate slot
```

Install ```slotpy``` through pip:

```bash
pip install slotpy
```

## Run:

From command line through the GUI:
```bash
python general.py
```

Try out the example notebook just for the plot:
-> examples/plotter_test_notebook.ipynb

